==> ukui-search_4.10.5.0.orig.tar.gz: ukui-search-4.10.5.0/translations/ukui-search/zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>UkuiSearch::BestListWidget</name>
    <message>
        <location filename="../../frontend/view/best-list-view.cpp" line="389"/>
        <source>Best Matches</source>
        <translation>最佳匹配</translation>
    </message>
</context>
<context>
    <name>UkuiSearch::ContentWidget</name>
    <message>
        <source>Recently Opened</source>
        <translation type="vanished">最近</translation>
    </message>
    <message>
        <source>Open Quickly</source>
        <translation type="vanished">快速入口</translation>
    </message>
    <message>
        <source>Commonly Used</source>
        <translation type="vanished">常用</translation>
    </message>
    <message>
        <source>Apps</source>
        <translation type="vanished">应用</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="vanished">配置项</translation>
    </message>
    <message>
        <source>Files</source>
        <translation type="vanished">文件</translation>
    </message>
    <message>
        <source>Dirs</source>
        <translation type="vanished">文件夹</translation>
    </message>
    <message>
        <source>File Contents</source>
        <translation type="vanished">文件内容</translation>
    </message>
    <message>
        <source>Best Matches</source>
        <translation type="vanished">最佳匹配</translation>
    </message>
    <message>
        <source>Web Pages</source>
        <translation type="vanished">网页</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="vanished">未知</translation>
    </message>
</context>
<context>
    <name>UkuiSearch::CreateIndexAskDialog</name>
    <message>
        <location filename="../../frontend/control/create-index-ask-dialog.cpp" line="42"/>
        <source>ukui-search</source>
        <translation>搜索</translation>
    </message>
    <message>
        <location filename="../../frontend/control/create-index-ask-dialog.cpp" line="71"/>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
    <message>
        <location filename="../../frontend/control/create-index-ask-dialog.cpp" line="78"/>
        <source>close</source>
        <translation>关闭</translation>
    </message>
    <message>
        <location filename="../../frontend/control/create-index-ask-dialog.cpp" line="96"/>
        <source>Creating index can help you get results more quickly. Would you like to create one?</source>
        <translation>创建索引可以快速获取搜索结果，是否创建？</translation>
    </message>
    <message>
        <location filename="../../frontend/control/create-index-ask-dialog.cpp" line="107"/>
        <source>Don&apos;t remind me again</source>
        <translation>不再提醒</translation>
    </message>
    <message>
        <source>Don&apos;t remind</source>
        <translation type="vanished">不再提醒</translation>
    </message>
    <message>
        <location filename="../../frontend/control/create-index-ask-dialog.cpp" line="118"/>
        <source>No</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../../frontend/control/create-index-ask-dialog.cpp" line="120"/>
        <source>Yes</source>
        <translation>确定</translation>
    </message>
</context>
<context>
    <name>UkuiSearch::FolderListItem</name>
    <message>
        <source>Delete the folder out of blacklist</source>
        <translation type="vanished">删除</translation>
    </message>
</context>
<context>
    <name>UkuiSearch::HomePage</name>
    <message>
        <source>Open Quickly</source>
        <translation type="vanished">快速入口</translation>
    </message>
    <message>
        <source>Recently Opened</source>
        <translation type="vanished">最近</translation>
    </message>
    <message>
        <source>Commonly Used</source>
        <translation type="vanished">常用</translation>
    </message>
</context>
<context>
    <name>UkuiSearch::MainWindow</name>
    <message>
        <location filename="../../frontend/mainwindow.cpp" line="73"/>
        <source>ukui-search</source>
        <translation>搜索</translation>
    </message>
    <message>
        <location filename="../../frontend/mainwindow.cpp" line="81"/>
        <source>Search Settings</source>
        <translation>设置搜索项</translation>
    </message>
    <message>
        <location filename="../../frontend/mainwindow.cpp" line="84"/>
        <source>Global Search</source>
        <translation>搜索</translation>
    </message>
    <message>
        <source>Search</source>
        <translation type="vanished">搜索</translation>
    </message>
</context>
<context>
    <name>UkuiSearch::OptionView</name>
    <message>
        <source>Open</source>
        <translation type="vanished">打开</translation>
    </message>
    <message>
        <source>Add Shortcut to Desktop</source>
        <translation type="vanished">添加到桌面快捷方式</translation>
    </message>
    <message>
        <source>Add Shortcut to Panel</source>
        <translation type="vanished">添加到任务栏快捷方式</translation>
    </message>
    <message>
        <source>Open path</source>
        <translation type="vanished">打开文件所在路径</translation>
    </message>
    <message>
        <source>Copy path</source>
        <translation type="vanished">复制文件路径</translation>
    </message>
    <message>
        <source>Install</source>
        <translation type="vanished">安装</translation>
    </message>
</context>
<context>
    <name>UkuiSearch::SearchBarHLayout</name>
    <message>
        <source>Search</source>
        <translation type="vanished">搜索</translation>
    </message>
</context>
<context>
    <name>UkuiSearch::SearchDetailView</name>
    <message>
        <source>Introduction: %1</source>
        <translation type="vanished">软件介绍: %1</translation>
    </message>
    <message>
        <source>Application</source>
        <translation type="vanished">应用</translation>
    </message>
    <message>
        <source>Document</source>
        <translation type="vanished">文件</translation>
    </message>
    <message>
        <source>Preview is not avaliable</source>
        <translation type="vanished">当前预览不可用</translation>
    </message>
    <message>
        <source>Path</source>
        <translation type="vanished">路径</translation>
    </message>
    <message>
        <source>Last time modified</source>
        <translation type="vanished">上次修改时间</translation>
    </message>
</context>
<context>
    <name>UkuiSearch::SearchLineEdit</name>
    <message>
        <location filename="../../frontend/control/search-line-edit.cpp" line="53"/>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
</context>
<context>
    <name>UkuiSearch::SettingsWidget</name>
    <message>
        <source>ukui-search-settings</source>
        <translation type="vanished">搜索</translation>
    </message>
    <message>
        <source>Search</source>
        <translation type="vanished">搜索</translation>
    </message>
    <message>
        <source>&lt;h2&gt;Settings&lt;/h2&gt;</source>
        <translation type="vanished">&lt;h2&gt;设置&lt;/h2&gt;</translation>
    </message>
    <message>
        <source>&lt;h3&gt;Index State&lt;/h3&gt;</source>
        <translation type="vanished">&lt;h3&gt;索引状态&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>&lt;h3&gt;File Index Settings&lt;/h3&gt;</source>
        <translation type="vanished">&lt;h3&gt;文件索引设置&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>Following folders will not be searched. You can set it by adding and removing folders.</source>
        <translation type="vanished">搜索将不再查看以下文件夹。通过增加和删除文件夹可进行文件索引设置。</translation>
    </message>
    <message>
        <source>Add ignored folders</source>
        <translation type="vanished">添加文件夹至黑名单</translation>
    </message>
    <message>
        <source>&lt;h3&gt;Search Engine Settings&lt;/h3&gt;</source>
        <translation type="vanished">&lt;h3&gt;搜索引擎设置&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>Please select search engine you preferred.</source>
        <translation type="vanished">设置互联网搜索引擎</translation>
    </message>
    <message>
        <source>baidu</source>
        <translation type="vanished">百度</translation>
    </message>
    <message>
        <source>sougou</source>
        <translation type="vanished">搜狗</translation>
    </message>
    <message>
        <source>360</source>
        <translation type="vanished">360</translation>
    </message>
    <message>
        <source>Whether to delete this directory?</source>
        <translation type="vanished">是否要删除此目录?</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="vanished">是(Y)</translation>
    </message>
    <message>
        <source>No</source>
        <translation type="vanished">否(N)</translation>
    </message>
    <message>
        <source>Creating ...</source>
        <translation type="vanished">正在索引...</translation>
    </message>
    <message>
        <source>Done</source>
        <translation type="vanished">索引完成</translation>
    </message>
    <message>
        <source>Index Entry: %1</source>
        <translation type="vanished">索引项: %1</translation>
    </message>
    <message>
        <source>Directories</source>
        <translation type="vanished">文件夹</translation>
    </message>
    <message>
        <source>select blocked folder</source>
        <translation type="vanished">选择屏蔽文件夹</translation>
    </message>
    <message>
        <source>Select</source>
        <translation type="vanished">选择</translation>
    </message>
    <message>
        <source>Position: </source>
        <translation type="vanished">位置：</translation>
    </message>
    <message>
        <source>FileName: </source>
        <translation type="vanished">名称：</translation>
    </message>
    <message>
        <source>FileType: </source>
        <translation type="vanished">类型：</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">取消</translation>
    </message>
    <message>
        <source>Choosen path is Empty!</source>
        <translation type="vanished">选择的路径不存在！</translation>
    </message>
    <message>
        <source>Choosen path is not in &quot;home&quot;!</source>
        <translation type="vanished">请选择家目录下的文件夹！</translation>
    </message>
    <message>
        <source>Its&apos; parent folder has been blocked!</source>
        <translation type="vanished">父文件夹已被屏蔽！</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="vanished">好的</translation>
    </message>
</context>
<context>
    <name>UkuiSearch::ShowMoreLabel</name>
    <message>
        <source>Show More...</source>
        <translation type="vanished">显示更多...</translation>
    </message>
    <message>
        <source>Retract</source>
        <translation type="vanished">收起</translation>
    </message>
    <message>
        <source>Loading</source>
        <translation type="vanished">加载中</translation>
    </message>
    <message>
        <source>Loading.</source>
        <translation type="vanished">加载中.</translation>
    </message>
    <message>
        <source>Loading..</source>
        <translation type="vanished">加载中..</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation type="vanished">加载中...</translation>
    </message>
</context>
<context>
    <name>UkuiSearch::UkuiSearchGui</name>
    <message>
        <location filename="../../frontend/ukui-search-gui.cpp" line="111"/>
        <source>Quit ukui-search application</source>
        <translation>退出搜索应用</translation>
    </message>
    <message>
        <location filename="../../frontend/ukui-search-gui.cpp" line="114"/>
        <source>Show main window</source>
        <translation>显示主页面</translation>
    </message>
    <message>
        <location filename="../../frontend/ukui-search-gui.cpp" line="117"/>
        <source>unregister a plugin with &lt;pluginName&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../frontend/ukui-search-gui.cpp" line="120"/>
        <source>register a plugin with &lt;pluginName&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../frontend/ukui-search-gui.cpp" line="123"/>
        <source>move &lt;pluginName&gt; to the target pos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../frontend/ukui-search-gui.cpp" line="126"/>
        <source>move plugin to &lt;index&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UkuiSearch::WebSearchWidget</name>
    <message>
        <source>Web Page</source>
        <translation type="vanished">网页搜索</translation>
    </message>
</context>
<context>
    <name>search</name>
    <message>
        <location filename="../../frontend/search-app-widget-plugin/provider/data/search.qml" line="115"/>
        <source>search</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> ukui-search_4.10.12.0.orig.tar.gz: ukui-search-4.10.12.0/translations/ukui-search/zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>UkuiSearch::BestListWidget</name>
    <message>
        <location filename="../../frontend/view/best-list-view.cpp" line="408"/>
        <source>Best Matches</source>
        <translation>最佳匹配</translation>
    </message>
</context>
<context>
    <name>UkuiSearch::ContentWidget</name>
    <message>
        <source>Recently Opened</source>
        <translation type="vanished">最近</translation>
    </message>
    <message>
        <source>Open Quickly</source>
        <translation type="vanished">快速入口</translation>
    </message>
    <message>
        <source>Commonly Used</source>
        <translation type="vanished">常用</translation>
    </message>
    <message>
        <source>Apps</source>
        <translation type="vanished">应用</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="vanished">配置项</translation>
    </message>
    <message>
        <source>Files</source>
        <translation type="vanished">文件</translation>
    </message>
    <message>
        <source>Dirs</source>
        <translation type="vanished">文件夹</translation>
    </message>
    <message>
        <source>File Contents</source>
        <translation type="vanished">文件内容</translation>
    </message>
    <message>
        <source>Best Matches</source>
        <translation type="vanished">最佳匹配</translation>
    </message>
    <message>
        <source>Web Pages</source>
        <translation type="vanished">网页</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="vanished">未知</translation>
    </message>
</context>
<context>
    <name>UkuiSearch::CreateIndexAskDialog</name>
    <message>
        <location filename="../../frontend/control/create-index-ask-dialog.cpp" line="42"/>
        <source>ukui-search</source>
        <translation>搜索</translation>
    </message>
    <message>
        <location filename="../../frontend/control/create-index-ask-dialog.cpp" line="71"/>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
    <message>
        <location filename="../../frontend/control/create-index-ask-dialog.cpp" line="78"/>
        <source>close</source>
        <translation>关闭</translation>
    </message>
    <message>
        <location filename="../../frontend/control/create-index-ask-dialog.cpp" line="96"/>
        <source>Creating index can help you get results more quickly. Would you like to create one?</source>
        <translation>创建索引可以快速获取搜索结果，是否创建？</translation>
    </message>
    <message>
        <location filename="../../frontend/control/create-index-ask-dialog.cpp" line="107"/>
        <source>Don&apos;t remind me again</source>
        <translation>不再提醒</translation>
    </message>
    <message>
        <source>Don&apos;t remind</source>
        <translation type="vanished">不再提醒</translation>
    </message>
    <message>
        <location filename="../../frontend/control/create-index-ask-dialog.cpp" line="118"/>
        <source>No</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../../frontend/control/create-index-ask-dialog.cpp" line="120"/>
        <source>Yes</source>
        <translation>确定</translation>
    </message>
</context>
<context>
    <name>UkuiSearch::FolderListItem</name>
    <message>
        <source>Delete the folder out of blacklist</source>
        <translation type="vanished">删除</translation>
    </message>
</context>
<context>
    <name>UkuiSearch::HomePage</name>
    <message>
        <source>Open Quickly</source>
        <translation type="vanished">快速入口</translation>
    </message>
    <message>
        <source>Recently Opened</source>
        <translation type="vanished">最近</translation>
    </message>
    <message>
        <source>Commonly Used</source>
        <translation type="vanished">常用</translation>
    </message>
</context>
<context>
    <name>UkuiSearch::MainWindow</name>
    <message>
        <location filename="../../frontend/mainwindow.cpp" line="73"/>
        <source>ukui-search</source>
        <translation>搜索</translation>
    </message>
    <message>
        <source>Search Settings</source>
        <translation type="vanished">设置搜索项</translation>
    </message>
    <message>
        <source>Global Search</source>
        <translation type="vanished">搜索</translation>
    </message>
    <message>
        <source>Search</source>
        <translation type="vanished">搜索</translation>
    </message>
</context>
<context>
    <name>UkuiSearch::OptionView</name>
    <message>
        <source>Open</source>
        <translation type="vanished">打开</translation>
    </message>
    <message>
        <source>Add Shortcut to Desktop</source>
        <translation type="vanished">添加到桌面快捷方式</translation>
    </message>
    <message>
        <source>Add Shortcut to Panel</source>
        <translation type="vanished">添加到任务栏快捷方式</translation>
    </message>
    <message>
        <source>Open path</source>
        <translation type="vanished">打开文件所在路径</translation>
    </message>
    <message>
        <source>Copy path</source>
        <translation type="vanished">复制文件路径</translation>
    </message>
    <message>
        <source>Install</source>
        <translation type="vanished">安装</translation>
    </message>
</context>
<context>
    <name>UkuiSearch::SearchBarHLayout</name>
    <message>
        <source>Search</source>
        <translation type="vanished">搜索</translation>
    </message>
</context>
<context>
    <name>UkuiSearch::SearchDetailView</name>
    <message>
        <source>Introduction: %1</source>
        <translation type="vanished">软件介绍: %1</translation>
    </message>
    <message>
        <source>Application</source>
        <translation type="vanished">应用</translation>
    </message>
    <message>
        <source>Document</source>
        <translation type="vanished">文件</translation>
    </message>
    <message>
        <source>Preview is not avaliable</source>
        <translation type="vanished">当前预览不可用</translation>
    </message>
    <message>
        <source>Path</source>
        <translation type="vanished">路径</translation>
    </message>
    <message>
        <source>Last time modified</source>
        <translation type="vanished">上次修改时间</translation>
    </message>
</context>
<context>
    <name>UkuiSearch::SearchLineEdit</name>
    <message>
        <location filename="../../frontend/control/search-line-edit.cpp" line="53"/>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
</context>
<context>
    <name>UkuiSearch::SettingsWidget</name>
    <message>
        <source>ukui-search-settings</source>
        <translation type="vanished">搜索</translation>
    </message>
    <message>
        <source>Search</source>
        <translation type="vanished">搜索</translation>
    </message>
    <message>
        <source>&lt;h2&gt;Settings&lt;/h2&gt;</source>
        <translation type="vanished">&lt;h2&gt;设置&lt;/h2&gt;</translation>
    </message>
    <message>
        <source>&lt;h3&gt;Index State&lt;/h3&gt;</source>
        <translation type="vanished">&lt;h3&gt;索引状态&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>&lt;h3&gt;File Index Settings&lt;/h3&gt;</source>
        <translation type="vanished">&lt;h3&gt;文件索引设置&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>Following folders will not be searched. You can set it by adding and removing folders.</source>
        <translation type="vanished">搜索将不再查看以下文件夹。通过增加和删除文件夹可进行文件索引设置。</translation>
    </message>
    <message>
        <source>Add ignored folders</source>
        <translation type="vanished">添加文件夹至黑名单</translation>
    </message>
    <message>
        <source>&lt;h3&gt;Search Engine Settings&lt;/h3&gt;</source>
        <translation type="vanished">&lt;h3&gt;搜索引擎设置&lt;/h3&gt;</translation>
    </message>
    <message>
        <source>Please select search engine you preferred.</source>
        <translation type="vanished">设置互联网搜索引擎</translation>
    </message>
    <message>
        <source>baidu</source>
        <translation type="vanished">百度</translation>
    </message>
    <message>
        <source>sougou</source>
        <translation type="vanished">搜狗</translation>
    </message>
    <message>
        <source>360</source>
        <translation type="vanished">360</translation>
    </message>
    <message>
        <source>Whether to delete this directory?</source>
        <translation type="vanished">是否要删除此目录?</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="vanished">是(Y)</translation>
    </message>
    <message>
        <source>No</source>
        <translation type="vanished">否(N)</translation>
    </message>
    <message>
        <source>Creating ...</source>
        <translation type="vanished">正在索引...</translation>
    </message>
    <message>
        <source>Done</source>
        <translation type="vanished">索引完成</translation>
    </message>
    <message>
        <source>Index Entry: %1</source>
        <translation type="vanished">索引项: %1</translation>
    </message>
    <message>
        <source>Directories</source>
        <translation type="vanished">文件夹</translation>
    </message>
    <message>
        <source>select blocked folder</source>
        <translation type="vanished">选择屏蔽文件夹</translation>
    </message>
    <message>
        <source>Select</source>
        <translation type="vanished">选择</translation>
    </message>
    <message>
        <source>Position: </source>
        <translation type="vanished">位置：</translation>
    </message>
    <message>
        <source>FileName: </source>
        <translation type="vanished">名称：</translation>
    </message>
    <message>
        <source>FileType: </source>
        <translation type="vanished">类型：</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">取消</translation>
    </message>
    <message>
        <source>Choosen path is Empty!</source>
        <translation type="vanished">选择的路径不存在！</translation>
    </message>
    <message>
        <source>Choosen path is not in &quot;home&quot;!</source>
        <translation type="vanished">请选择家目录下的文件夹！</translation>
    </message>
    <message>
        <source>Its&apos; parent folder has been blocked!</source>
        <translation type="vanished">父文件夹已被屏蔽！</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="vanished">好的</translation>
    </message>
</context>
<context>
    <name>UkuiSearch::ShowMoreLabel</name>
    <message>
        <source>Show More...</source>
        <translation type="vanished">显示更多...</translation>
    </message>
    <message>
        <source>Retract</source>
        <translation type="vanished">收起</translation>
    </message>
    <message>
        <source>Loading</source>
        <translation type="vanished">加载中</translation>
    </message>
    <message>
        <source>Loading.</source>
        <translation type="vanished">加载中.</translation>
    </message>
    <message>
        <source>Loading..</source>
        <translation type="vanished">加载中..</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation type="vanished">加载中...</translation>
    </message>
</context>
<context>
    <name>UkuiSearch::UkuiSearchGui</name>
    <message>
        <location filename="../../frontend/ukui-search-gui.cpp" line="111"/>
        <source>Quit ukui-search application</source>
        <translation>退出搜索应用</translation>
    </message>
    <message>
        <location filename="../../frontend/ukui-search-gui.cpp" line="114"/>
        <source>Show main window</source>
        <translation>显示主页面</translation>
    </message>
    <message>
        <location filename="../../frontend/ukui-search-gui.cpp" line="117"/>
        <source>unregister a plugin with &lt;pluginName&gt;</source>
        <translation>注销插件&lt;pluginName&gt;</translation>
    </message>
    <message>
        <location filename="../../frontend/ukui-search-gui.cpp" line="120"/>
        <source>register a plugin with &lt;pluginName&gt;</source>
        <translation>注册插件&lt;pluginName&gt;</translation>
    </message>
    <message>
        <location filename="../../frontend/ukui-search-gui.cpp" line="123"/>
        <source>move &lt;pluginName&gt; to the target pos</source>
        <translation>将插件&lt;pluginName&gt;移动至目标位置</translation>
    </message>
    <message>
        <location filename="../../frontend/ukui-search-gui.cpp" line="126"/>
        <source>move plugin to &lt;index&gt;</source>
        <translation>将插件移动到&lt;index&gt;</translation>
    </message>
</context>
<context>
    <name>UkuiSearch::WebSearchWidget</name>
    <message>
        <source>Web Page</source>
        <translation type="vanished">网页搜索</translation>
    </message>
</context>
<context>
    <name>search</name>
    <message>
        <location filename="../../frontend/search-app-widget-plugin/provider/data/search.qml" line="132"/>
        <source>search</source>
        <translation>搜索</translation>
    </message>
</context>
</TS>
